@@ -1,5 +1,5 @@
 """Editor commands"""
-from __future__ import division, absolute_import, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 import os
 import re
 import sys
@@ -584,6 +584,7 @@ class ResetHard(ResetCommand):
 
 class RestoreWorktree(ConfirmAction):
     """Reset the worktree using the "git read-tree" command"""
+
     @staticmethod
     def tooltip(ref):
         tooltip = N_(
@@ -617,6 +618,7 @@ class RestoreWorktree(ConfirmAction):
 
 class UndoLastCommit(ResetCommand):
     """Undo the last commit"""
+
     # NOTE: this is the similar to ResetSoft() with an additional check for
     # published commits and different messages.
     def __init__(self, context):
@@ -850,7 +852,6 @@ class RemoteEdit(ContextCommand):
 
 
 class RemoveFromSettings(ConfirmAction):
-
     def __init__(self, context, repo, entry, icon=None):
         super(RemoveFromSettings, self).__init__(context)
         self.context = context
@@ -863,7 +864,6 @@ class RemoveFromSettings(ConfirmAction):
 
 
 class RemoveBookmark(RemoveFromSettings):
-
     def confirm(self):
         entry = self.entry
         title = msg = N_('Delete Bookmark?')
@@ -1299,7 +1299,7 @@ class Diff(EditModel):
     def __init__(self, context, filename, cached=False, deleted=False):
         super(Diff, self).__init__(context)
         opts = {}
-        if cached:
+        if cached and gitcmds.is_valid_ref(context, self.model.head):
             opts['ref'] = self.model.head
         self.new_filename = filename
         self.new_mode = self.model.mode_worktree
@@ -1587,8 +1587,7 @@ class LoadCommitMessageFromOID(ContextCommand):
 
 
 class PrepareCommitMessageHook(ContextCommand):
-    """Use the cola-prepare-commit-msg hook to prepare the commit message
-    """
+    """Use the cola-prepare-commit-msg hook to prepare the commit message"""
 
     UNDOABLE = True
 
@@ -1817,8 +1816,7 @@ class NewBareRepo(ContextCommand):
 
 
 def unix_path(path, is_win32=utils.is_win32):
-    """Git for Windows requires unix paths, so force them here
-    """
+    """Git for Windows requires unix paths, so force them here"""
     if is_win32():
         path = path.replace('\\', '/')
         first = path[0]
@@ -1832,7 +1830,10 @@ def unix_path(path, is_win32=utils.is_win32):
 def sequence_editor():
     """Set GIT_SEQUENCE_EDITOR for running git-cola-sequence-editor"""
     xbase = unix_path(resources.command('git-cola-sequence-editor'))
-    editor = core.list2cmdline([unix_path(sys.executable), xbase])
+    if utils.is_win32():
+        editor = core.list2cmdline([unix_path(sys.executable), xbase])
+    else:
+        editor = core.list2cmdline([xbase])
     return editor
 
 
@@ -2253,8 +2254,14 @@ class ShowUntracked(EditModel):
     def __init__(self, context, filename):
         super(ShowUntracked, self).__init__(context)
         self.new_filename = filename
-        self.new_mode = self.model.mode_untracked
-        self.new_diff_text = self.read(filename)
+        if gitcmds.is_binary(context, filename):
+            self.new_mode = self.model.mode_untracked
+            self.new_diff_text = self.read(filename)
+        else:
+            self.new_mode = self.model.mode_untracked_diff
+            self.new_diff_text = gitcmds.diff_helper(
+                self.context, filename=filename, cached=False, untracked=True
+            )
         self.new_diff_type = main.Types.TEXT
         self.new_file_type = main.Types.TEXT
 
@@ -2332,8 +2339,7 @@ def check_conflicts(context, unmerged):
 
 
 def is_conflict_free(path):
-    """Return True if `path` contains no conflict markers
-    """
+    """Return True if `path` contains no conflict markers"""
     rgx = re.compile(r'^(<<<<<<<|\|\|\|\|\|\|\||>>>>>>>) ')
     try:
         with core.xopen(path, 'r') as f:
@@ -2493,6 +2499,34 @@ class StageUntracked(StageCarefully):
         self.paths = self.model.untracked
 
 
+class StageModifiedAndUntracked(StageCarefully):
+    """Stage all untracked files."""
+
+    @staticmethod
+    def name():
+        return N_('Stage Modified and Untracked')
+
+    def init_paths(self):
+        self.paths = self.model.modified + self.model.untracked
+
+
+class StageOrUnstageAll(ContextCommand):
+    """If the selection is staged, unstage it, otherwise stage"""
+    @staticmethod
+    def name():
+        return N_('Stage / Unstage All')
+
+    def do(self):
+        if self.model.staged:
+            do(Unstage, self.context, self.model.staged)
+        else:
+            if self.cfg.get('cola.safemode', False):
+                unstaged = self.model.modified
+            else:
+                unstaged = self.model.modified + self.model.untracked
+            do(Stage, self.context, unstaged)
+
+
 class StageOrUnstage(ContextCommand):
     """If the selection is staged, unstage it, otherwise stage"""
 
@@ -2656,7 +2690,7 @@ class UnstageSelected(Unstage):
     """Unstage selected files."""
 
     def __init__(self, context):
-        staged = self.selection.staged
+        staged = context.selection.staged
         super(UnstageSelected, self).__init__(context, staged)
 
 
