@@ -1,5 +1,5 @@
 # pylint: disable=unused-import,redefined-builtin,undefined-variable
-from __future__ import absolute_import, division, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 import os
 import sys
 
@@ -10,27 +10,27 @@ except ImportError:
     from urllib import parse  # noqa
 
 
-PY2 = sys.version_info[0] == 2
-PY3 = sys.version_info[0] >= 3
+PY_VERSION = sys.version_info[:2]  # (2, 7)
+PY_VERSION_MAJOR = PY_VERSION[0]
+PY2 = PY_VERSION_MAJOR == 2
+PY3 = PY_VERSION_MAJOR >= 3
 PY26_PLUS = PY2 and sys.version_info[1] >= 6
 WIN32 = sys.platform == 'win32' or sys.platform == 'cygwin'
 ENCODING = 'utf-8'
 
 
 if PY3:
-
     def bstr(x, encoding=ENCODING):
         return bytes(x, encoding=encoding)
 
-
 elif PY26_PLUS:
     bstr = bytes
 else:
     # Python <= 2.5
     bstr = str
 
-if PY3:
 
+if PY3:
     def bchr(i):
         return bytes([i])
 
@@ -56,7 +56,6 @@ def setenv(key, value):
     """Compatibility wrapper for setting environment variables
 
     Why?  win32 requires putenv().  UNIX only requires os.environ.
-
     """
     if not PY3 and isinstance(value, ustr):
         value = value.encode(ENCODING, 'replace')
@@ -81,8 +80,7 @@ def byte_offset_to_int_converter():
 
     Indexing into python3 bytes returns ints, Python2 returns str.
     Thus, on Python2 we need to use `ord()` to convert the byte into
-    an integration.  It's already an int on Python3, so we use no_op there.
-
+    an integer.  It's already an int on Python3, so we use no_op there.
     """
     if PY2:
         result = ord
