@@ -4,7 +4,7 @@ The @interruptable functions retry when system calls are interrupted,
 e.g. when python raises an IOError or OSError with errno == EINTR.
 
 """
-from __future__ import division, absolute_import, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 import functools
 import itertools
 import mimetypes
@@ -83,8 +83,7 @@ def decode_maybe(value, encoding, errors='strict'):
 
 
 def decode(value, encoding=None, errors='strict'):
-    """decode(encoded_string) returns an unencoded unicode string
-    """
+    """decode(encoded_string) returns an unencoded unicode string"""
     if value is None:
         result = None
     elif isinstance(value, ustr):
@@ -114,8 +113,7 @@ def decode(value, encoding=None, errors='strict'):
 
 
 def encode(string, encoding=None):
-    """encode(unencoded_string) returns a string encoded in utf-8
-    """
+    """encode(unencoded_string) returns a string encoded in utf-8"""
     if not isinstance(string, ustr):
         return string
     return string.encode(encoding or ENCODING, 'replace')
