@@ -1,4 +1,4 @@
-from __future__ import division, absolute_import, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 import argparse
 import sys
 
@@ -52,5 +52,5 @@ def parse_args(argv=None):
 def cmd_dag(args):
     """Run git-dag via the `git cola dag` sub-command"""
     context = app.application_init(args)
-    view = git_dag(context, args=args, settings=args.settings, show=False)
+    view = git_dag(context, args=args, show=False)
     return app.application_start(context, view)
