@@ -1,4 +1,4 @@
-from __future__ import division, absolute_import, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 import errno
 import functools
 
@@ -22,7 +22,9 @@ def decorator(caller, func=None):
             @functools.wraps(f)
             def _caller(*args, **opts):
                 return caller(f, *args, **opts)
+
             return _caller
+
         _decorator.func = caller
         return _decorator
 
@@ -30,6 +32,7 @@ def decorator(caller, func=None):
     @functools.wraps(func)
     def _decorated(*args, **opts):
         return caller(func, *args, **opts)
+
     _decorated.func = func
     return _decorated
 
@@ -61,7 +64,7 @@ def _memoize(func, *args, **opts):
 
 @decorator
 def interruptable(func, *args, **opts):
-    """Handle interruptable system calls
+    """Handle interruptible system calls
 
     OSX and others are known to interrupt system calls
 
