@@ -6,7 +6,7 @@ Linux monitoring uses using inotify.
 Windows monitoring uses pywin32 and the ReadDirectoryChanges function.
 
 """
-from __future__ import division, absolute_import, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 import errno
 import os
 import os.path
