@@ -1,4 +1,4 @@
-from __future__ import division, absolute_import, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 from functools import partial
 import errno
 import os
@@ -170,9 +170,7 @@ class Paths(object):
 
 
 def find_git_directory(path):
-    """Perform Git repository discovery
-
-    """
+    """Perform Git repository discovery"""
     return Paths(
         git_dir=core.getenv('GIT_DIR'), worktree=core.getenv('GIT_WORK_TREE')
     ).get(path)
