@@ -1,4 +1,4 @@
-from __future__ import division, absolute_import, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 from binascii import unhexlify
 import copy
 import fnmatch
@@ -10,6 +10,7 @@ import struct
 from . import core
 from . import observable
 from . import utils
+from . import version
 from .compat import int_types
 from .git import STDOUT
 from .compat import ustr
@@ -18,8 +19,8 @@ BUILTIN_READER = os.environ.get('GIT_COLA_BUILTIN_CONFIG_READER', False)
 
 _USER_CONFIG = core.expanduser(join('~', '.gitconfig'))
 _USER_XDG_CONFIG = core.expanduser(
-    join(core.getenv('XDG_CONFIG_HOME', join('~', '.config')),
-         'git', 'config'))
+    join(core.getenv('XDG_CONFIG_HOME', join('~', '.config')), 'git', 'config')
+)
 
 
 def create(context):
@@ -29,9 +30,11 @@ def create(context):
 
 def _stat_info(git):
     # Try /etc/gitconfig as a fallback for the system config
-    paths = [('system', '/etc/gitconfig'),
-             ('user', _USER_XDG_CONFIG),
-             ('user', _USER_CONFIG)]
+    paths = [
+        ('system', '/etc/gitconfig'),
+        ('user', _USER_XDG_CONFIG),
+        ('user', _USER_CONFIG),
+    ]
     config = git.git_path('config')
     if config:
         paths.append(('repo', config))
@@ -67,14 +70,13 @@ def _cache_key(git):
 
 def _config_to_python(v):
     """Convert a Git config string into a Python value"""
-
     if v in ('true', 'yes'):
         v = True
     elif v in ('false', 'no'):
         v = False
     else:
         try:
-            v = int(v)
+            v = int(v)  # pylint: disable=redefined-variable-type
         except ValueError:
             pass
     return v
@@ -122,6 +124,7 @@ class GitConfig(observable.Observable):
         self._configs = []
         self._config_files = {}
         self._attr_cache = {}
+        self._binary_cache = {}
         self._find_config_files()
 
     def reset(self):
@@ -129,6 +132,7 @@ class GitConfig(observable.Observable):
         self._configs = []
         self._config_files.clear()
         self._attr_cache = {}
+        self._binary_cache = {}
         self._find_config_files()
         self.reset_values()
 
@@ -186,16 +190,13 @@ class GitConfig(observable.Observable):
         self.reset_values()
 
         if 'system' in self._config_files:
-            self._system.update(
-                self.read_config(self._config_files['system']))
+            self._system.update(self.read_config(self._config_files['system']))
 
         if 'user' in self._config_files:
-            self._user.update(
-                self.read_config(self._config_files['user']))
+            self._user.update(self.read_config(self._config_files['user']))
 
         if 'repo' in self._config_files:
-            self._repo.update(
-                self.read_config(self._config_files['repo']))
+            self._repo.update(self.read_config(self._config_files['repo']))
 
         for dct in (self._system, self._user):
             self._user_or_system.update(dct)
@@ -212,7 +213,10 @@ class GitConfig(observable.Observable):
             return self._read_config_file(path)
 
         dest = {}
-        args = ('--null', '--file', path, '--list')
+        if version.check_git(self, 'config-includes'):
+            args = ('--null', '--file', path, '--list', '--includes')
+        else:
+            args = ('--null', '--file', path, '--list')
         config_lines = self.git.config(*args)[STDOUT].split('\0')
         for line in config_lines:
             if not line:
@@ -311,8 +315,7 @@ class GitConfig(observable.Observable):
 
         """
         result = []
-        status, out, _ = self.git.config(
-            key, z=True, get_all=True, show_origin=True)
+        status, out, _ = self.git.config(key, z=True, get_all=True, show_origin=True)
         if status == 0:
             current_source = ''
             current_result = []
@@ -379,8 +382,25 @@ class GitConfig(observable.Observable):
         return self.get('gui.encoding', default=None)
 
     def is_per_file_attrs_enabled(self):
-        return self.get('cola.fileattributes',
-                        fn=lambda: os.path.exists('.gitattributes'))
+        return self.get(
+            'cola.fileattributes', fn=lambda: os.path.exists('.gitattributes')
+        )
+
+    def is_binary(self, path):
+        """Return True if the file has the binary attribute set"""
+        if not self.is_per_file_attrs_enabled():
+            return None
+        cache = self._binary_cache
+        try:
+            value = cache[path]
+        except KeyError:
+            value = cache[path] = self._is_binary(path)
+        return value
+
+    def _is_binary(self, path):
+        """Return the file encoding for a path"""
+        value = self.check_attr('binary', path)
+        return value == 'set'
 
     def file_encoding(self, path):
         if not self.is_per_file_attrs_enabled():
@@ -389,21 +409,27 @@ class GitConfig(observable.Observable):
         try:
             value = cache[path]
         except KeyError:
-            value = cache[path] = (self._file_encoding(path) or
-                                   self.gui_encoding())
+            value = cache[path] = self._file_encoding(path) or self.gui_encoding()
         return value
 
     def _file_encoding(self, path):
         """Return the file encoding for a path"""
-        status, out, _ = self.git.check_attr('encoding', '--', path)
-        if status != 0:
-            return None
-        header = '%s: encoding: ' % path
-        if out.startswith(header):
-            encoding = out[len(header):].strip()
-            if encoding not in ('unspecified', 'unset', 'set'):
-                return encoding
-        return None
+        encoding = self.check_attr('encoding', path)
+        if encoding in ('unspecified', 'unset', 'set'):
+            result = None
+        else:
+            result = encoding
+        return result
+
+    def check_attr(self, attr, path):
+        """Check file attributes for a path"""
+        value = None
+        status, out, _ = self.git.check_attr(attr, '--', path)
+        if status == 0:
+            header = '%s: %s: ' % (path, attr)
+            if out.startswith(header):
+                value = out[len(header) :].strip()
+        return value
 
     def get_guitool_opts(self, name):
         """Return the guitool.<name> namespace as a dict
@@ -414,21 +440,18 @@ class GitConfig(observable.Observable):
         """
         prefix = len('guitool.%s.' % name)
         guitools = self.find('guitool.%s.*' % name)
-        return dict([(key[prefix:], value)
-                     for (key, value) in guitools.items()])
+        return dict([(key[prefix:], value) for (key, value) in guitools.items()])
 
     def get_guitool_names(self):
         guitools = self.find('guitool.*.cmd')
         prefix = len('guitool.')
         suffix = len('.cmd')
-        return sorted([name[prefix:-suffix]
-                       for (name, _) in guitools.items()])
+        return sorted([name[prefix:-suffix] for (name, _) in guitools.items()])
 
     def get_guitool_names_and_shortcuts(self):
         """Return guitool names and their configured shortcut"""
         names = self.get_guitool_names()
-        return [(name, self.get('guitool.%s.shortcut' % name))
-                for name in names]
+        return [(name, self.get('guitool.%s.shortcut' % name)) for name in names]
 
     def terminal(self):
         term = self.get('cola.terminal', default=None)
@@ -439,8 +462,7 @@ class GitConfig(observable.Observable):
                 # Try to find Git's sh.exe directory in
                 # one of the typical locations
                 pf = os.environ.get('ProgramFiles', 'C:\\Program Files')
-                pf32 = os.environ.get('ProgramFiles(x86)',
-                                      'C:\\Program Files (x86)')
+                pf32 = os.environ.get('ProgramFiles(x86)', 'C:\\Program Files (x86)')
                 pf64 = os.environ.get('ProgramW6432', 'C:\\Program Files')
 
                 for p in [pf64, pf32, pf, 'C:\\']:
@@ -463,11 +485,22 @@ class GitConfig(observable.Observable):
         value = self.get('cola.color.%s' % key, default=default)
         struct_layout = core.encode('BBB')
         try:
+            # pylint: disable=no-member
             r, g, b = struct.unpack(struct_layout, unhex(value))
         except (struct.error, TypeError):
+            # pylint: disable=no-member
             r, g, b = struct.unpack(struct_layout, unhex(default))
         return (r, g, b)
 
+    def hooks(self):
+        """Return the path to the git hooks directory"""
+        gitdir_hooks = self.git.git_path('hooks')
+        return self.get('core.hookspath', default=gitdir_hooks)
+
+    def hooks_path(self, *paths):
+        """Return a path from within the git hooks directory"""
+        return os.path.join(self.hooks(), *paths)
+
 
 def python_to_git(value):
     if isinstance(value, bool):
