@@ -1,6 +1,5 @@
 """i18n and l10n support for git-cola"""
-from __future__ import division, absolute_import, unicode_literals
-
+from __future__ import absolute_import, division, print_function, unicode_literals
 import gettext as _gettext
 import os
 import sys
@@ -20,8 +19,8 @@ def gettext(s):
         # Python 3 compat
         _translation.ugettext = _translation.gettext
         txt = _translation.gettext(s)
-    if txt[-6:-4] == '@@':  # handle @@verb / @@noun
-        txt = txt[:-6]
+    # handle @@verb / @@noun
+    txt = txt.replace('@@verb', '').replace('@@noun', '')
     return txt
 
 
@@ -40,21 +39,21 @@ def N_(s):
 
 
 def install(locale):
+    # pylint: disable=global-statement
     global _translation
     if sys.platform == 'win32':
         _check_win32_locale()
     if locale:
-        compat.setenv('LANGUAGE', locale)
-        compat.setenv('LANG', locale)
-        compat.setenv('LC_MESSAGES', locale)
+        _set_language(locale)
     _install_custom_language()
     _gettext.textdomain('messages')
-    _translation = _gettext.translation('git-cola',
-                                        localedir=_get_locale_dir(),
-                                        fallback=True)
+    _translation = _gettext.translation(
+        'git-cola', localedir=_get_locale_dir(), fallback=True
+    )
 
 
 def uninstall():
+    # pylint: disable=global-statement
     global _translation
     _translation = _null_translation
 
@@ -69,11 +68,18 @@ def _install_custom_language():
     if not core.exists(lang_file):
         return
     try:
-        lang = core.read(lang_file).strip()
-    except:
+        locale = core.read(lang_file).strip()
+    except (OSError, IOError):
         return
-    if lang:
-        compat.setenv('LANGUAGE', lang)
+    if locale:
+        _set_language(locale)
+
+
+def _set_language(locale):
+    compat.setenv('LANGUAGE', locale)
+    compat.setenv('LANG', locale)
+    compat.setenv('LC_ALL', locale)
+    compat.setenv('LC_MESSAGES', locale)
 
 
 def _check_win32_locale():
@@ -82,9 +88,10 @@ def _check_win32_locale():
             break
     else:
         lang = None
-        import locale
+        import locale  # pylint: disable=all
+
         try:
-            import ctypes
+            import ctypes  # pylint: disable=all
         except ImportError:
             # use only user's default locale
             lang = locale.getdefaultlocale()[0]
