@@ -1,10 +1,11 @@
 """Launcher and command line interface to git-cola"""
-from __future__ import absolute_import, division, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 import argparse
 import sys
 
 from . import app
 from . import cmds
+from . import compat
 from . import core
 
 
@@ -33,8 +34,13 @@ def winmain():
 
 def parse_args(argv):
     parser = argparse.ArgumentParser()
-    subparser = parser.add_subparsers(title='valid commands')
+    # Newer versions of argparse (Python 3.6+) emit an error message for
+    # "--help-commands" unless we register the flag on the main parser.
+    if compat.PY_VERSION >= (3, 6):
+        add_help_options(parser)
+        parser.set_defaults(func=lambda _: parser.print_help())
 
+    subparser = parser.add_subparsers(title='valid commands')
     add_cola_command(subparser)
     add_about_command(subparser)
     add_am_command(subparser)
@@ -62,6 +68,16 @@ def parse_args(argv):
     return parser.parse_args(argv)
 
 
+def add_help_options(parser):
+    """Add the --help-commands flag to the parser"""
+    parser.add_argument(
+        '--help-commands',
+        default=False,
+        action='store_true',
+        help='show available sub-commands',
+    )
+
+
 def add_command(parent, name, description, func):
     parser = parent.add_parser(str(name), help=description)
     parser.set_defaults(func=func)
@@ -74,12 +90,7 @@ def add_cola_command(subparser):
     parser.add_argument(
         '--amend', default=False, action='store_true', help='start in amend mode'
     )
-    parser.add_argument(
-        '--help-commands',
-        default=False,
-        action='store_true',
-        help='show available sub-commands',
-    )
+    add_help_options(parser)
     parser.add_argument(
         '--status-filter', '-s', metavar='<path>', default='', help='status path filter'
     )
