@@ -1,8 +1,5 @@
-# Copyright (C) 2007-2018 David Aguilar
-"""This module provides the central cola model.
-"""
-from __future__ import division, absolute_import, unicode_literals
-
+"""The central cola model"""
+from __future__ import absolute_import, division, print_function, unicode_literals
 import os
 
 from .. import core
@@ -18,17 +15,23 @@ def create(context):
     return MainModel(context)
 
 
+# pylint: disable=too-many-public-methods
 class MainModel(Observable):
     """Repository status model"""
+
     # TODO this class can probably be split apart into a DiffModel,
     # CommitMessageModel, StatusModel, and an AppStatusStateMachine.
 
     # Observable messages
     message_about_to_update = 'about_to_update'
+    message_previous_contents = 'previous_contents'
     message_commit_message_changed = 'commit_message_changed'
     message_diff_text_changed = 'diff_text_changed'
     message_diff_text_updated = 'diff_text_updated'
+    # "diff_type" {text,image} represents the diff viewer mode.
     message_diff_type_changed = 'diff_type_changed'
+    # "file_type" {text,image} represents the selected file type.
+    message_file_type_changed = 'file_type_changed'
     message_filename_changed = 'filename_changed'
     message_images_changed = 'images_changed'
     message_mode_about_to_change = 'mode_about_to_change'
@@ -43,6 +46,7 @@ class MainModel(Observable):
     mode_worktree = 'worktree'  # Comparing index to worktree
     mode_diffstat = 'diffstat'  # Showing a diffstat
     mode_untracked = 'untracked'  # Dealing with an untracked file
+    mode_untracked_diff = 'untracked-diff'  # Diffing an untracked file
     mode_index = 'index'  # Comparing index to last commit
     mode_amend = 'amend'  # Amending a commit
 
@@ -50,13 +54,12 @@ class MainModel(Observable):
     modes_undoable = set((mode_amend, mode_index, mode_worktree))
 
     # Modes where we can partially stage files
-    modes_stageable = set((mode_amend, mode_worktree, mode_untracked))
+    modes_stageable = set((mode_amend, mode_worktree, mode_untracked_diff))
 
     # Modes where we can partially unstage files
     modes_unstageable = set((mode_amend, mode_index))
 
-    unstaged = property(
-        lambda self: self.modified + self.unmerged + self.untracked)
+    unstaged = property(lambda self: self.modified + self.unmerged + self.untracked)
     """An aggregate of the modified, unmerged, and untracked file lists."""
 
     def __init__(self, context, cwd=None):
@@ -73,7 +76,8 @@ class MainModel(Observable):
         self.lfs = False
         self.head = 'HEAD'
         self.diff_text = ''
-        self.diff_type = 'text'  # text, image
+        self.diff_type = Types.TEXT
+        self.file_type = Types.TEXT
         self.mode = self.mode_none
         self.filename = None
         self.is_merging = False
@@ -145,10 +149,14 @@ class MainModel(Observable):
         """
         lfs_filter = self.cfg.get('filter.lfs.clean', default=False)
         lfs_dir = lfs_filter and self.git.git_path('lfs')
-        lfs_hook = lfs_filter and self.git.git_path('hooks', 'post-merge')
-        return (lfs_filter
-                and lfs_dir and core.exists(lfs_dir)
-                and lfs_hook and core.exists(lfs_hook))
+        lfs_hook = lfs_filter and self.cfg.hooks_path('post-merge')
+        return (
+            lfs_filter
+            and lfs_dir
+            and core.exists(lfs_dir)
+            and lfs_hook
+            and core.exists(lfs_hook)
+        )
 
     def set_commitmsg(self, msg, notify=True):
         self.commitmsg = msg
@@ -177,8 +185,17 @@ class MainModel(Observable):
 
     def set_diff_type(self, diff_type):  # text, image
         """Set the diff type to either text or image"""
+        changed = diff_type != self.diff_type
         self.diff_type = diff_type
-        self.notify_observers(self.message_diff_type_changed, diff_type)
+        if changed:
+            self.notify_observers(self.message_diff_type_changed, diff_type)
+
+    def set_file_type(self, file_type):  # text, image
+        """Set the file type to either text or image"""
+        changed = file_type != self.file_type
+        self.file_type = file_type
+        if changed:
+            self.notify_observers(self.message_file_type_changed, file_type)
 
     def set_images(self, images):
         """Update the images shown in the preview pane"""
@@ -212,6 +229,13 @@ class MainModel(Observable):
         self.update_file_status()
 
     def emit_about_to_update(self):
+        self.notify_observers(
+            self.message_previous_contents,
+            self.staged,
+            self.unmerged,
+            self.modified,
+            self.untracked
+        )
         self.notify_observers(self.message_about_to_update)
 
     def emit_updated(self):
@@ -251,8 +275,12 @@ class MainModel(Observable):
         context = self.context
         display_untracked = prefs.display_untracked(context)
         state = gitcmds.worktree_state(
-            context, head=self.head, update_index=update_index,
-            display_untracked=display_untracked, paths=self.filter_paths)
+            context,
+            head=self.head,
+            update_index=update_index,
+            display_untracked=display_untracked,
+            paths=self.filter_paths,
+        )
         self.staged = state.get('staged', [])
         self.modified = state.get('modified', [])
         self.unmerged = state.get('unmerged', [])
@@ -271,8 +299,9 @@ class MainModel(Observable):
             self.set_diff_text('')
 
     def is_empty(self):
-        return not(bool(self.staged or self.modified or
-                        self.unmerged or self.untracked))
+        return not (
+            bool(self.staged or self.modified or self.unmerged or self.untracked)
+        )
 
     def is_empty_repository(self):
         return not self.local_branches
@@ -288,7 +317,8 @@ class MainModel(Observable):
         )
         sort_key = sort_types[self.ref_sort]
         local_branches, remote_branches, tags = gitcmds.all_refs(
-            context, split=True, sort_key=sort_key)
+            context, split=True, sort_key=sort_key
+        )
         self.local_branches = local_branches
         self.remote_branches = remote_branches
         self.tags = tags
@@ -361,16 +391,17 @@ class MainModel(Observable):
 
     def push(self, remote, remote_branch='', local_branch='', **opts):
         # Swap the branches in push mode (reverse of fetch)
-        opts.update(dict(local_branch=remote_branch,
-                         remote_branch=local_branch))
+        opts.update(dict(local_branch=remote_branch, remote_branch=local_branch))
         result = run_remote_action(
-            self.context, self.git.push, remote, push=True, **opts)
+            self.context, self.git.push, remote, push=True, **opts
+        )
         self.update_refs()
         return result
 
     def pull(self, remote, **opts):
         result = run_remote_action(
-            self.context, self.git.pull, remote, pull=True, **opts)
+            self.context, self.git.pull, remote, pull=True, **opts
+        )
         # Pull can result in merge conflicts
         self.update_refs()
         self.update_files(update_index=False, emit=True)
@@ -426,20 +457,30 @@ class MainModel(Observable):
         self.update_refs()
 
 
+class Types(object):
+    """File types (used for image diff modes)"""
+
+    IMAGE = 'image'
+    TEXT = 'text'
+
+
 # Helpers
 # pylint: disable=too-many-arguments
-def remote_args(context, remote,
-                local_branch='',
-                remote_branch='',
-                ff_only=False,
-                force=False,
-                no_ff=False,
-                tags=False,
-                rebase=False,
-                pull=False,
-                push=False,
-                set_upstream=False,
-                prune=False):
+def remote_args(
+    context,
+    remote,
+    local_branch='',
+    remote_branch='',
+    ff_only=False,
+    force=False,
+    no_ff=False,
+    tags=False,
+    rebase=False,
+    pull=False,
+    push=False,
+    set_upstream=False,
+    prune=False,
+):
     """Return arguments for git fetch/push/pull"""
 
     args = [remote]
