@@ -1,6 +1,5 @@
-# Copyright (C) 2007-2018 David Aguilar and contributors
 """Miscellaneous Qt utility functions."""
-from __future__ import division, absolute_import, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 import os
 
 from qtpy import compat
@@ -475,7 +474,8 @@ def set_clipboard(text):
         return
     clipboard = QtWidgets.QApplication.clipboard()
     clipboard.setText(text, QtGui.QClipboard.Clipboard)
-    clipboard.setText(text, QtGui.QClipboard.Selection)
+    if not utils.is_darwin() and not utils.is_win32():
+        clipboard.setText(text, QtGui.QClipboard.Selection)
     persist_clipboard()
 
 
@@ -799,11 +799,11 @@ class DockTitleBarWidget(QtWidgets.QFrame):
         self.toggle_button.setToolTip(tooltip)
 
 
-def create_dock(title, parent, stretch=True, widget=None, fn=None):
+def create_dock(name, title, parent, stretch=True, widget=None, fn=None):
     """Create a dock widget and set it up accordingly."""
     dock = QtWidgets.QDockWidget(parent)
     dock.setWindowTitle(title)
-    dock.setObjectName(title)
+    dock.setObjectName(name)
     titlebar = DockTitleBarWidget(dock, title, stretch=stretch)
     dock.setTitleBarWidget(titlebar)
     dock.setAutoFillBackground(True)
@@ -913,16 +913,17 @@ class BlockSignals(object):
 
     def __init__(self, *widgets):
         self.widgets = widgets
-        self.values = {}
+        self.values = []
 
     def __enter__(self):
-        for w in self.widgets:
-            self.values[w] = w.blockSignals(True)
+        """Block Qt signals for all of the captured widgets"""
+        self.values = [widget.blockSignals(True) for widget in self.widgets]
         return self
 
     def __exit__(self, exc_type, exc_val, exc_tb):
-        for w in self.widgets:
-            w.blockSignals(self.values[w])
+        """Restore Qt signals when we exit the scope"""
+        for (widget, value) in zip(self.widgets, self.values):
+            widget.blockSignals(value)
 
 
 class Channel(QtCore.QObject):
@@ -1078,3 +1079,60 @@ class ImageFormats(object):
     def ok(self, filename):
         _, ext = os.path.splitext(filename)
         return ext.lower() in self.extensions
+
+
+def set_scrollbar_values(widget, hscroll_value, vscroll_value):
+    """Set scrollbars to the specified values"""
+    hscroll = widget.horizontalScrollBar()
+    if hscroll and hscroll_value is not None:
+        hscroll.setValue(hscroll_value)
+
+    vscroll = widget.verticalScrollBar()
+    if vscroll and vscroll_value is not None:
+        vscroll.setValue(vscroll_value)
+
+
+def get_scrollbar_values(widget):
+    """Return the current (hscroll, vscroll) scrollbar values for a widget"""
+    hscroll = widget.horizontalScrollBar()
+    if hscroll:
+        hscroll_value = get(hscroll)
+    else:
+        hscroll_value = None
+    vscroll = widget.verticalScrollBar()
+    if vscroll:
+        vscroll_value = get(vscroll)
+    else:
+        vscroll_value = None
+    return (hscroll_value, vscroll_value)
+
+
+def scroll_to_item(widget, item):
+    """Scroll to an item while retaining the horizontal scroll position"""
+    hscroll = None
+    hscrollbar = widget.horizontalScrollBar()
+    if hscrollbar:
+        hscroll = get(hscrollbar)
+    widget.scrollToItem(item)
+    if hscroll is not None:
+        hscrollbar.setValue(hscroll)
+
+
+def select_item(widget, item):
+    """Scroll to and make a QTreeWidget item selected and current"""
+    scroll_to_item(widget, item)
+    widget.setCurrentItem(item)
+    item.setSelected(True)
+
+
+def get_selected_values(widget, top_level_idx, values):
+    """Map the selected items under the top-level item to the values list"""
+    # Get the top-level item
+    item = widget.topLevelItem(top_level_idx)
+    return tree_selection(item, values)
+
+
+def get_selected_items(widget, idx):
+    """Return the selected items under the top-level item"""
+    item = widget.topLevelItem(idx)
+    return tree_selection_items(item)
