@@ -1,5 +1,5 @@
-"""Provides themes generator"""
-from __future__ import absolute_import, division, unicode_literals
+"""Themes generators"""
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from qtpy import QtGui
 
