@@ -1,6 +1,5 @@
-# Copyright (C) 2007-2018 David Aguilar and contributors
-"""This module provides miscellaneous utility functions."""
-from __future__ import division, absolute_import, unicode_literals
+"""Miscellaneous utility functions"""
+from __future__ import absolute_import, division, print_function, unicode_literals
 import copy
 import os
 import random
@@ -148,19 +147,61 @@ def dirname(path, current_dir=''):
 
 
 def splitpath(path):
-    """Split paths using '/' regardless of platform
+    """Split paths using '/' regardless of platform"""
+    return path.split('/')
+
+
+def split(name):
+    """Split a path-like name. Returns tuple "(head, tail)" where "tail" is
+    everything after the final slash. The "head" may be empty.
+
+    This is the same as os.path.split() but only uses '/' as the delimiter.
+
+    >>> split('a/b/c')
+    ('a/b', 'c')
+
+    >>> split('xyz')
+    ('', 'xyz')
 
     """
-    return path.split('/')
+    return (dirname(name), basename(name))
 
 
 def join(*paths):
     """Join paths using '/' regardless of platform
 
+    >>> join('a', 'b', 'c')
+    'a/b/c'
+
     """
     return '/'.join(paths)
 
 
+def normalize_slash(value):
+    """Strip and normalize slashes in a string
+
+    >>> normalize_slash('///Meow///Cat///')
+    'Meow/Cat'
+
+    """
+    value = value.strip('/')
+    new_value = value.replace('//', '/')
+    while new_value != value:
+        value = new_value
+        new_value = value.replace('//', '/')
+    return value
+
+
+def pathjoin(paths):
+    """Join a list of paths using '/' regardless of platform
+
+    >>> pathjoin(['a', 'b', 'c'])
+    'a/b/c'
+
+    """
+    return join(*paths)
+
+
 def pathset(path):
     """Return all of the path components for the specified path
 
@@ -194,7 +235,7 @@ def strip_prefix(prefix, string):
     """Return string, without the prefix. Blow up if string doesn't
     start with prefix."""
     assert string.startswith(prefix)
-    return string[len(prefix):]
+    return string[len(prefix) :]
 
 
 def sanitize(s):
@@ -246,7 +287,7 @@ def shell_split(s):
 
 def tmp_filename(label, suffix=''):
     label = 'git-cola-' + label.replace('/', '-').replace('\\', '-')
-    fd = tempfile.NamedTemporaryFile(prefix=label+'-', suffix=suffix)
+    fd = tempfile.NamedTemporaryFile(prefix=label + '-', suffix=suffix)
     fd.close()
     return fd.name
 
@@ -287,10 +328,12 @@ class Group(object):
 
     def __getattr__(self, name):
         """Return a function that relays calls to the group"""
+
         def relay(*args, **kwargs):
             for member in self._members:
                 method = getattr(member, name)
                 method(*args, **kwargs)
+
         setattr(self, name, relay)
         return relay
 
@@ -359,7 +402,6 @@ def slice_fn(input_items, map_fn):
 
 
 class seq(object):
-
     def __init__(self, sequence):
         self.seq = sequence
 
