@@ -1,4 +1,4 @@
-from __future__ import division, absolute_import, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from ..i18n import N_
 from .. import cmds
@@ -17,13 +17,15 @@ def cmd_action(parent, cmd, context, fn, *keys):
 
     """
     return qtutils.add_action(
-        parent, cmd.name(), lambda: cmds.do(cmd, context, fn()), *keys)
+        parent, cmd.name(), lambda: cmds.do(cmd, context, fn()), *keys
+    )
 
 
 def default_app_action(context, parent, fn):
     """Open paths with the OS-default app -> QAction"""
-    action = cmd_action(parent, cmds.OpenDefaultApp, context, fn,
-                        hotkeys.PRIMARY_ACTION)
+    action = cmd_action(
+        parent, cmds.OpenDefaultApp, context, fn, hotkeys.PRIMARY_ACTION
+    )
     action.setIcon(icons.default_app())
     return action
 
@@ -31,9 +33,13 @@ def default_app_action(context, parent, fn):
 def edit_action(context, parent, *keys):
     """Launch an editor -> QAction"""
     action = qtutils.add_action_with_status_tip(
-        parent, cmds.LaunchEditor.name(),
+        parent,
+        cmds.LaunchEditor.name(),
         N_('Edit selected paths'),
-        cmds.run(cmds.LaunchEditor, context), hotkeys.EDIT, *keys)
+        cmds.run(cmds.LaunchEditor, context),
+        hotkeys.EDIT,
+        *keys
+    )
     action.setIcon(icons.edit())
     return action
 
@@ -48,16 +54,20 @@ def parent_dir_action(context, parent, fn):
 
 def refresh_action(context, parent):
     """Refresh the repository state -> QAction"""
-    return qtutils.add_action(parent, cmds.Refresh.name(),
-                              cmds.run(cmds.Refresh, context),
-                              hotkeys.REFRESH)
+    return qtutils.add_action(
+        parent, cmds.Refresh.name(), cmds.run(cmds.Refresh, context), hotkeys.REFRESH
+    )
 
 
 def terminal_action(context, parent, fn):
     """Launch a terminal -> QAction"""
     action = None
     if cmds.LaunchTerminal.is_available(context):
-        action = cmd_action(parent, cmds.LaunchTerminal, context,
-                            lambda: utils.select_directory(fn()),
-                            hotkeys.TERMINAL)
+        action = cmd_action(
+            parent,
+            cmds.LaunchTerminal,
+            context,
+            lambda: utils.select_directory(fn()),
+            hotkeys.TERMINAL,
+        )
     return action
