@@ -1,4 +1,4 @@
-from __future__ import division, absolute_import, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 import collections
 import itertools
 import math
@@ -278,56 +278,44 @@ def viewer_actions(widget):
             icons.compare(),
             qtutils.add_action(
                 widget, N_('Diff this -> selected'), widget.proxy.diff_this_selected
-            )
+            ),
         ),
         'diff_selected_this': set_icon(
             icons.compare(),
             qtutils.add_action(
                 widget, N_('Diff selected -> this'), widget.proxy.diff_selected_this
-            )
+            ),
         ),
         'create_branch': set_icon(
             icons.branch(),
-            qtutils.add_action(
-                widget, N_('Create Branch'), widget.proxy.create_branch
-            )
+            qtutils.add_action(widget, N_('Create Branch'), widget.proxy.create_branch),
         ),
         'create_patch': set_icon(
             icons.save(),
-            qtutils.add_action(
-                widget, N_('Create Patch'), widget.proxy.create_patch
-            )
+            qtutils.add_action(widget, N_('Create Patch'), widget.proxy.create_patch),
         ),
         'create_tag': set_icon(
             icons.tag(),
-            qtutils.add_action(
-                widget, N_('Create Tag'), widget.proxy.create_tag
-            )
+            qtutils.add_action(widget, N_('Create Tag'), widget.proxy.create_tag),
         ),
         'create_tarball': set_icon(
             icons.file_zip(),
             qtutils.add_action(
                 widget, N_('Save As Tarball/Zip...'), widget.proxy.create_tarball
-            )
+            ),
         ),
         'cherry_pick': set_icon(
-            icons.style_dialog_apply(),
-            qtutils.add_action(
-                widget, N_('Cherry Pick'), widget.proxy.cherry_pick
-            )
+            icons.cherry_pick(),
+            qtutils.add_action(widget, N_('Cherry Pick'), widget.proxy.cherry_pick),
         ),
         'revert': set_icon(
-            icons.undo(),
-            qtutils.add_action(widget, N_('Revert'), widget.proxy.revert)
+            icons.undo(), qtutils.add_action(widget, N_('Revert'), widget.proxy.revert)
         ),
         'diff_commit': set_icon(
             icons.diff(),
             qtutils.add_action(
-                widget,
-                N_('Launch Diff Tool'),
-                widget.proxy.show_diff,
-                hotkeys.DIFF
-            )
+                widget, N_('Launch Diff Tool'), widget.proxy.show_diff, hotkeys.DIFF
+            ),
         ),
         'diff_commit_all': set_icon(
             icons.diff(),
@@ -335,62 +323,59 @@ def viewer_actions(widget):
                 widget,
                 N_('Launch Directory Diff Tool'),
                 widget.proxy.show_dir_diff,
-                hotkeys.DIFF_SECONDARY
-            )
+                hotkeys.DIFF_SECONDARY,
+            ),
         ),
         'checkout_detached': qtutils.add_action(
-            widget, N_('Checkout Detached HEAD'),
-            widget.proxy.checkout_detached
+            widget, N_('Checkout Detached HEAD'), widget.proxy.checkout_detached
         ),
         'reset_soft': set_icon(
             icons.style_dialog_reset(),
             qtutils.add_action(
                 widget, N_('Reset Branch (Soft)'), widget.proxy.reset_soft
-            )
+            ),
         ),
         'reset_mixed': set_icon(
             icons.style_dialog_reset(),
             qtutils.add_action(
-                widget,
-                N_('Reset Branch and Stage (Mixed)'),
-                widget.proxy.reset_mixed
-            )
+                widget, N_('Reset Branch and Stage (Mixed)'), widget.proxy.reset_mixed
+            ),
         ),
         'reset_keep': set_icon(
             icons.style_dialog_reset(),
             qtutils.add_action(
                 widget,
                 N_('Restore Worktree and Reset All (Keep Unstaged Edits)'),
-                widget.proxy.reset_keep
-            )
+                widget.proxy.reset_keep,
+            ),
         ),
         'reset_merge': set_icon(
             icons.style_dialog_reset(),
             qtutils.add_action(
                 widget,
                 N_('Restore Worktree and Reset All (Merge)'),
-                widget.proxy.reset_merge
-            )
+                widget.proxy.reset_merge,
+            ),
         ),
         'reset_hard': set_icon(
             icons.style_dialog_reset(),
             qtutils.add_action(
                 widget,
                 N_('Restore Worktree and Reset All (Hard)'),
-                widget.proxy.reset_hard
-            )
+                widget.proxy.reset_hard,
+            ),
         ),
         'restore_worktree': set_icon(
             icons.edit(),
             qtutils.add_action(
                 widget, N_('Restore Worktree'), widget.proxy.restore_worktree
-            )
+            ),
         ),
         'save_blob': set_icon(
             icons.save(),
             qtutils.add_action(
                 widget, N_('Grab File...'), widget.proxy.save_blob_dialog
-            )
+            ),
         ),
         'copy': set_icon(
             icons.copy(),
@@ -398,8 +383,8 @@ def viewer_actions(widget):
                 widget,
                 N_('Copy SHA-1'),
                 widget.proxy.copy_to_clipboard,
-                hotkeys.COPY_SHA1
-            )
+                hotkeys.COPY_SHA1,
+            ),
         ),
     }
 
@@ -643,15 +628,15 @@ class GitDAG(standard.MainWindow):
         self.controls_widget = QtWidgets.QWidget()
         self.controls_widget.setLayout(self.controls_layout)
 
-        self.log_dock = qtutils.create_dock(N_('Log'), self, stretch=False)
+        self.log_dock = qtutils.create_dock('Log', N_('Log'), self, stretch=False)
         self.log_dock.setWidget(self.treewidget)
         log_dock_titlebar = self.log_dock.titleBarWidget()
         log_dock_titlebar.add_corner_widget(self.controls_widget)
 
-        self.file_dock = qtutils.create_dock(N_('Files'), self)
+        self.file_dock = qtutils.create_dock('Files', N_('Files'), self)
         self.file_dock.setWidget(self.filewidget)
 
-        self.diff_dock = qtutils.create_dock(N_('Diff'), self)
+        self.diff_dock = qtutils.create_dock('Diff', N_('Diff'), self)
         self.diff_dock.setWidget(self.diffwidget)
 
         self.graph_controls_layout = qtutils.hbox(
@@ -666,7 +651,7 @@ class GitDAG(standard.MainWindow):
         self.graph_controls_widget = QtWidgets.QWidget()
         self.graph_controls_widget.setLayout(self.graph_controls_layout)
 
-        self.graphview_dock = qtutils.create_dock(N_('Graph'), self)
+        self.graphview_dock = qtutils.create_dock('Graph', N_('Graph'), self)
         self.graphview_dock.setWidget(self.graphview)
         graph_titlebar = self.graphview_dock.titleBarWidget()
         graph_titlebar.add_corner_widget(self.graph_controls_widget)
@@ -1224,6 +1209,7 @@ class Commit(QtWidgets.QGraphicsItem):
         self.edges = {}
 
     def blockSignals(self, blocked):
+        """Disable notifications during sections that cause notification loops"""
         self.notifier.notification_enabled = not blocked
 
     def itemChange(self, change, value):
@@ -1246,7 +1232,7 @@ class Commit(QtWidgets.QGraphicsItem):
                     self.brush = self.commit_color
                 color = self.outline_color
             commit_pen = QtGui.QPen()
-            commit_pen.setWidth(1.0)
+            commit_pen.setWidth(1)
             commit_pen.setColor(color)
             self.commit_pen = commit_pen
 
@@ -1519,9 +1505,8 @@ class GraphView(QtWidgets.QGraphicsView, ViewerMixin):
                 item = self.items[oid]
             except KeyError:
                 continue
-            item.blockSignals(True)
-            item.setSelected(True)
-            item.blockSignals(False)
+            with qtutils.BlockSignals(item):
+                item.setSelected(True)
             item_rect = item.sceneTransform().mapRect(item.boundingRect())
             self.ensureVisible(item_rect)
 
