@@ -1,4 +1,4 @@
-from __future__ import absolute_import, division, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 import os
 import math
 
@@ -20,13 +20,15 @@ large_margin = scale(12)
 
 no_spacing = 0
 spacing = scale(4)
+titlebar_spacing = scale(8)
+button_spacing = scale(12)
 
 cursor_width = scale(2)
 handle_width = scale(4)
-button_spacing = scale(12)
 tool_button_height = scale(28)
 
-small_icon = scale(16)
+default_icon = scale(16)
+small_icon = scale(12)
 medium_icon = scale(48)
 large_icon = scale(96)
 huge_icon = scale(192)
@@ -35,6 +37,7 @@ max_size = scale(4096)
 
 border = max(1, scale(0.5))
 checkbox = scale(12)
+radio = scale(22)
 
 logo_text = 24
 
