@@ -1,4 +1,4 @@
-from __future__ import division, absolute_import, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 import os
 import re
 
@@ -404,20 +404,24 @@ class Viewer(QtWidgets.QFrame):
         self.setFocusProxy(self.text)
 
     def export_state(self, state):
-        state['show_diff_line_numbers'] = self.text.show_line_numbers()
+        state['show_diff_line_numbers'] = self.options.show_line_numbers.isChecked()
         state['image_diff_mode'] = self.options.image_mode.currentIndex()
         state['image_zoom_mode'] = self.options.zoom_mode.currentIndex()
+        state['word_wrap'] = self.options.enable_word_wrapping.isChecked()
         return state
 
     def apply_state(self, state):
         diff_numbers = bool(state.get('show_diff_line_numbers', False))
-        self.text.enable_line_numbers(diff_numbers)
+        self.set_line_numbers(diff_numbers, update=True)
 
         image_mode = utils.asint(state.get('image_diff_mode', 0))
         self.options.image_mode.set_index(image_mode)
 
         zoom_mode = utils.asint(state.get('image_zoom_mode', 0))
         self.options.zoom_mode.set_index(zoom_mode)
+
+        word_wrap = bool(state.get('word_wrap', True))
+        self.set_word_wrapping(word_wrap, update=True)
         return True
 
     def set_diff_type(self, diff_type):
@@ -435,8 +439,17 @@ class Viewer(QtWidgets.QFrame):
         # The "file type" is whether the file itself is an image.
         self.options.set_file_type(file_type)
 
-    def update_options(self):
-        self.text.update_options()
+    def set_options(self):
+        """Emit a signal indicating that options have changed"""
+        self.text.set_options()
+
+    def set_line_numbers(self, enabled, update=False):
+        """Enable/disable line numbers in the text widget"""
+        self.text.set_line_numbers(enabled, update=update)
+
+    def set_word_wrapping(self, enabled, update=False):
+        """Enable/disable word wrapping in the text widget"""
+        self.text.set_word_wrapping(enabled, update=update)
 
     def reset(self):
         self.image.pixmap = QtGui.QPixmap()
@@ -588,7 +601,12 @@ class Options(QtWidgets.QWidget):
             N_('Show whole surrounding functions of changes')
         )
 
-        self.show_line_numbers = self.add_option(N_('Show line numbers'))
+        self.show_line_numbers = qtutils.add_action_bool(
+            self, N_('Show line numbers'), self.set_line_numbers, True
+        )
+        self.enable_word_wrapping = qtutils.add_action_bool(
+            self, N_('Enable word wrapping'), self.set_word_wrapping, True
+        )
 
         self.options = qtutils.create_action_button(
             tooltip=N_('Diff Options'), icon=icons.configure()
@@ -620,8 +638,11 @@ class Options(QtWidgets.QWidget):
         menu.addAction(self.ignore_space_at_eol)
         menu.addAction(self.ignore_space_change)
         menu.addAction(self.ignore_all_space)
-        menu.addAction(self.show_line_numbers)
+        menu.addSeparator()
         menu.addAction(self.function_context)
+        menu.addAction(self.show_line_numbers)
+        menu.addSeparator()
+        menu.addAction(self.enable_word_wrapping)
 
         # Layouts
         layout = qtutils.hbox(
@@ -642,10 +663,12 @@ class Options(QtWidgets.QWidget):
         self.setFocusPolicy(Qt.NoFocus)
 
     def set_file_type(self, file_type):
+        """Set whether we are viewing an image file type"""
         is_image = file_type == main.Types.IMAGE
         self.toggle_image_diff.setVisible(is_image)
 
     def set_diff_type(self, diff_type):
+        """Toggle between image and text diffs"""
         is_text = diff_type == main.Types.TEXT
         is_image = diff_type == main.Types.IMAGE
         self.options.setVisible(is_text)
@@ -657,11 +680,13 @@ class Options(QtWidgets.QWidget):
             self.toggle_image_diff.setIcon(icons.visualize())
 
     def add_option(self, title):
-        action = qtutils.add_action(self, title, self.update_options)
+        """Add a diff option which calls set_options() on change"""
+        action = qtutils.add_action(self, title, self.set_options)
         action.setCheckable(True)
         return action
 
-    def update_options(self):
+    def set_options(self):
+        """Update diff options in response to UI events"""
         space_at_eol = get(self.ignore_space_at_eol)
         space_change = get(self.ignore_space_change)
         all_space = get(self.ignore_all_space)
@@ -669,7 +694,14 @@ class Options(QtWidgets.QWidget):
         gitcmds.update_diff_overrides(
             space_at_eol, space_change, all_space, function_context
         )
-        self.widget.update_options()
+        self.widget.set_options()
+
+    def set_line_numbers(self, value):
+        self.widget.set_line_numbers(value, update=False)
+
+    def set_word_wrapping(self, value):
+        """Respond to Qt action callbacks"""
+        self.widget.set_word_wrapping(value, update=False)
 
 
 # pylint: disable=too-many-ancestors
@@ -689,8 +721,13 @@ class DiffEditor(DiffTextEdit):
 
         # "Diff Options" tool menu
         self.options = options
+
         self.action_apply_selection = qtutils.add_action(
-            self, 'Apply', self.apply_selection, hotkeys.STAGE_DIFF
+            self,
+            'Apply',
+            self.apply_selection,
+            hotkeys.STAGE_DIFF,
+            hotkeys.STAGE_DIFF_ALT,
         )
 
         self.action_revert_selection = qtutils.add_action(
@@ -729,24 +766,37 @@ class DiffEditor(DiffTextEdit):
         enabled = False
         s = self.selection_model.selection()
         model = self.model
-        if s.modified and model.stageable():
-            if s.modified[0] in model.submodules:
+        if model.stageable():
+            item = s.modified[0] if s.modified else None
+            if item in model.submodules:
                 pass
-            elif s.modified[0] not in model.unstaged_deleted:
+            elif item not in model.unstaged_deleted:
                 enabled = True
         self.action_revert_selection.setEnabled(enabled)
 
-    def enable_line_numbers(self, enabled):
+    def set_line_numbers(self, enabled, update=False):
         """Enable/disable the diff line number display"""
         self.numbers.setVisible(enabled)
-        self.options.show_line_numbers.setChecked(enabled)
+        if update:
+            with qtutils.BlockSignals(self.options.show_line_numbers):
+                self.options.show_line_numbers.setChecked(enabled)
+        # Refresh the display. Not doing this results in the display not
+        # correctly displaying the line numbers widget until the text scrolls.
+        self.set_value(self.value())
 
-    def show_line_numbers(self):
-        """Return True if we should show line numbers"""
-        return get(self.options.show_line_numbers)
+    def set_word_wrapping(self, enabled, update=False):
+        """Enable/disable word wrapping"""
+        if update:
+            with qtutils.BlockSignals(self.options.enable_word_wrapping):
+                self.options.enable_word_wrapping.setChecked(enabled)
+        if enabled:
+            self.setWordWrapMode(QtGui.QTextOption.WordWrap)
+            self.setLineWrapMode(QtWidgets.QPlainTextEdit.WidgetWidth)
+        else:
+            self.setWordWrapMode(QtGui.QTextOption.NoWrap)
+            self.setLineWrapMode(QtWidgets.QPlainTextEdit.NoWrap)
 
-    def update_options(self):
-        self.numbers.setVisible(self.show_line_numbers())
+    def set_options(self):
         self.options_changed.emit()
 
     # Qt overrides
@@ -765,8 +815,8 @@ class DiffEditor(DiffTextEdit):
                 self.stage_or_unstage.setText(N_('Unstage'))
             menu.addAction(self.stage_or_unstage)
 
-        if s.modified and model.stageable():
-            item = s.modified[0]
+        if model.stageable():
+            item = s.modified[0] if s.modified else None
             if item in model.submodules:
                 path = core.abspath(item)
                 action = menu.addAction(
@@ -907,7 +957,7 @@ class DiffEditor(DiffTextEdit):
     def apply_selection(self):
         model = self.model
         s = self.selection_model.single_selection()
-        if model.stageable() and s.modified:
+        if model.stageable() and (s.modified or s.untracked):
             self.process_diff_selection()
         elif model.unstageable():
             self.process_diff_selection(reverse=True)
@@ -1116,9 +1166,8 @@ class TextLabel(QtWidgets.QLabel):
     def resizeEvent(self, event):
         if self._elide:
             self.update_text(event.size().width())
-            block = self.blockSignals(True)
-            self.setText(self._display)
-            self.blockSignals(block)
+            with qtutils.BlockSignals(self):
+                self.setText(self._display)
         QtWidgets.QLabel.resizeEvent(self, event)
 
 
