@@ -1,5 +1,5 @@
 """File finder widgets"""
-from __future__ import division, absolute_import, unicode_literals
+from __future__ import absolute_import, division, print_function, unicode_literals
 import os
 from functools import partial
 
