@@ -9,6 +9,7 @@ from .. import qtutils
 from ..i18n import N_
 from ..icons import folder
 from ..interaction import Interaction
+from . import completion
 from . import defs
 from .diff import DiffTextEdit
 from .standard import Dialog
@@ -18,32 +19,28 @@ def select_commits(context, title, revs, summaries, multiselect=True):
     """Use the SelectCommits to select commits from a list."""
     model = Model(revs, summaries)
     parent = qtutils.active_window()
-    dialog = SelectCommits(
-        context, model, parent, title, multiselect=multiselect)
+    dialog = SelectCommits(context, model, parent, title, multiselect=multiselect)
     return dialog.select_commits()
 
 
-def select_commits_and_output(context, title, revs, summaries,
-                              multiselect=True):
+def select_commits_and_output(context, title, revs, summaries, multiselect=True):
     """Select commits from a list and output path"""
     model = Model(revs, summaries)
     parent = qtutils.active_window()
-    dialog = SelectCommitsAndOutput(context, model, parent, title,
-                                    multiselect=multiselect)
+    dialog = SelectCommitsAndOutput(
+        context, model, parent, title, multiselect=multiselect
+    )
     return dialog.select_commits_and_output()
 
 
 class Model(object):
-
     def __init__(self, revs, summaries):
         self.revisions = revs
         self.summaries = summaries
 
 
 class SelectCommits(Dialog):
-
-    def __init__(self, context, model,
-                 parent=None, title=None, multiselect=True):
+    def __init__(self, context, model, parent=None, title=None, multiselect=True):
         Dialog.__init__(self, parent)
         self.context = context
         self.model = model
@@ -60,27 +57,39 @@ class SelectCommits(Dialog):
 
         self.commit_text = DiffTextEdit(context, self, whitespace=False)
 
-        self.label = QtWidgets.QLabel()
-        self.label.setText(N_('Revision Expression:'))
-        self.revision = QtWidgets.QLineEdit()
+        self.revision_label = QtWidgets.QLabel()
+        self.revision_label.setText(N_('Revision Expression:'))
+        self.revision = completion.GitRefLineEdit(context)
         self.revision.setReadOnly(True)
 
+        self.search_label = QtWidgets.QLabel()
+        self.search_label.setText(N_('Search:'))
+        self.search = QtWidgets.QLineEdit()
+        self.search.setReadOnly(False)
+
+        # pylint: disable=no-member
+        self.search.textChanged.connect(self.search_list)
+
         self.select_button = qtutils.ok_button(N_('Select'), enabled=False)
-        self.close_button = qtutils.close_button()
 
         # Make the list widget slightly larger
-        self.splitter = qtutils.splitter(Qt.Vertical,
-                                         self.commits, self.commit_text)
+        self.splitter = qtutils.splitter(Qt.Vertical, self.commits, self.commit_text)
         self.splitter.setSizes([100, 150])
 
-        self.input_layout = qtutils.hbox(defs.no_margin, defs.button_spacing,
-                                         self.close_button,
-                                         qtutils.STRETCH,
-                                         self.label, self.revision,
-                                         self.select_button)
+        self.input_layout = qtutils.hbox(
+            defs.no_margin,
+            defs.spacing,
+            self.search_label,
+            self.search,
+            qtutils.STRETCH,
+            self.revision_label,
+            self.revision,
+            self.select_button,
+        )
 
-        self.main_layout = qtutils.vbox(defs.margin, defs.margin,
-                                        self.splitter, self.input_layout)
+        self.main_layout = qtutils.vbox(
+            defs.margin, defs.margin, self.input_layout, self.splitter
+        )
         self.setLayout(self.main_layout)
 
         # pylint: disable=no-member
@@ -88,7 +97,6 @@ class SelectCommits(Dialog):
         commits.itemDoubleClicked.connect(self.commit_oid_double_clicked)
 
         qtutils.connect_button(self.select_button, self.accept)
-        qtutils.connect_button(self.close_button, self.reject)
 
         self.init_state(None, self.resize_widget, parent)
 
@@ -135,24 +143,30 @@ class SelectCommits(Dialog):
         if oid:
             self.accept()
 
+    def search_list(self, text):
+        if text:
+            for i in range(self.commits.count()):
+                self.commits.item(i).setHidden(True)
+        search_items = self.commits.findItems(text, Qt.MatchContains)
+        for items in search_items:
+            items.setHidden(False)
+
 
 class SelectCommitsAndOutput(SelectCommits):
-
-    def __init__(self, context, model,
-                 parent=None, title=None, multiselect=True):
-        SelectCommits.__init__(
-            self, context, model, parent, title, multiselect)
+    def __init__(self, context, model, parent=None, title=None, multiselect=True):
+        SelectCommits.__init__(self, context, model, parent, title, multiselect)
 
         self.output_dir = 'output'
         self.select_output = qtutils.create_button(
-            tooltip=N_('Select output dir'), icon=folder())
+            tooltip=N_('Select output dir'), icon=folder()
+        )
         self.output_text = QtWidgets.QLineEdit()
         self.output_text.setReadOnly(True)
         self.output_text.setText(self.output_dir)
 
-        output_layout = qtutils.hbox(defs.no_margin, defs.no_spacing,
-                                     self.select_output,
-                                     self.output_text)
+        output_layout = qtutils.hbox(
+            defs.no_margin, defs.no_spacing, self.select_output, self.output_text
+        )
 
         self.input_layout.insertLayout(1, output_layout)
         qtutils.connect_button(self.select_output, self.show_output_dialog)
@@ -164,8 +178,9 @@ class SelectCommitsAndOutput(SelectCommits):
         return {'to_export': to_export, 'output': output}
 
     def show_output_dialog(self):
-        self.output_dir = qtutils.opendir_dialog(N_('Select output directory'),
-                                                 self.output_dir)
+        self.output_dir = qtutils.opendir_dialog(
+            N_('Select output directory'), self.output_dir
+        )
         if not self.output_dir:
             return
 
