@@ -1,7 +1,6 @@
 """build_pot command for setup.py"""
-# pylint: disable=attribute-defined-outside-init
-# pylint: disable=no-name-in-module,import-error
-from __future__ import absolute_import, division, unicode_literals
+# pylint: disable=attribute-defined-outside-init,import-error,no-name-in-module
+from __future__ import absolute_import, division, print_function, unicode_literals
 import os
 import glob
 from distutils import log
@@ -133,11 +132,8 @@ class build_pot(Command):
 
 
 def _force_LF(src, dst=None):
-    f = open(src, 'rU')
-    try:
-        content = f.read()
-    finally:
-        f.close()
+    with open(src, 'rb') as f:
+        content = f.read().decode('utf-8')
     if dst is None:
         dst = src
     f = open(dst, 'wb')
