@@ -1,7 +1,7 @@
 """Script for preparing the html output of the Sphinx documentation system for
 github pages. """
-
-from __future__  import absolute_import, division, unicode_literals
+# flake8: noqa
+from __future__ import absolute_import, division, unicode_literals
 
 VERSION = (1, 1, 0, 'dev')
 
@@ -12,7 +12,7 @@ __contact__ = "http://github.com/michaeljones"
 __homepage__ = "http://github.com/michaeljones/sphinx-to-github"
 __docformat__ = "restructuredtext"
 
-from sphinxtogithub.sphinxtogithub import (
+from .sphinxtogithub import (
     setup,
     sphinx_extension,
     LayoutFactory,
@@ -26,6 +26,5 @@ from sphinxtogithub.sphinxtogithub import (
     DirHelper,
     FileSystemHelper,
     OperationsFactory,
-    HandlerFactory
+    HandlerFactory,
 )
-
