@@ -15,7 +15,6 @@ def stdout(msg):
 
 
 class DirHelper(object):
-
     def __init__(self, is_dir, list_dir, walk, rmtree):
 
         self.is_dir = is_dir
@@ -25,7 +24,6 @@ class DirHelper(object):
 
 
 class FileSystemHelper(object):
-
     def __init__(self, open_, path_join, move, exists):
 
         self.open_ = open_
@@ -67,7 +65,6 @@ class FileHandler(object):
 
 
 class Remover(object):
-
     def __init__(self, exists, remove):
         self.exists = exists
         self.remove = remove
@@ -79,7 +76,6 @@ class Remover(object):
 
 
 class ForceRename(object):
-
     def __init__(self, renamer, remove):
 
         self.renamer = renamer
@@ -92,7 +88,6 @@ class ForceRename(object):
 
 
 class VerboseRename(object):
-
     def __init__(self, renamer, stream):
 
         self.renamer = renamer
@@ -103,7 +98,7 @@ class VerboseRename(object):
         self.stream.write(
             "Renaming directory '%s' -> '%s'\n"
             % (os.path.basename(from_), os.path.basename(to))
-            )
+        )
 
         self.renamer(from_, to)
 
@@ -140,7 +135,6 @@ class DirectoryHandler(object):
 
 
 class HandlerFactory(object):
-
     def create_file_handler(self, name, replacers, opener):
 
         return FileHandler(name, replacers, opener)
@@ -151,7 +145,6 @@ class HandlerFactory(object):
 
 
 class OperationsFactory(object):
-
     def create_force_rename(self, renamer, remover):
 
         return ForceRename(renamer, remover)
@@ -193,6 +186,7 @@ class NullLayout(object):
     """
     Layout class that does nothing when asked to process
     """
+
     def process(self):
         pass
 
@@ -200,8 +194,16 @@ class NullLayout(object):
 class LayoutFactory(object):
     "Creates a layout object"
 
-    def __init__(self, operations_factory, handler_factory,
-                 file_helper, dir_helper, verbose, stream, force):
+    def __init__(
+        self,
+        operations_factory,
+        handler_factory,
+        file_helper,
+        dir_helper,
+        verbose,
+        stream,
+        force,
+    ):
 
         self.operations_factory = operations_factory
         self.handler_factory = handler_factory
@@ -221,27 +223,28 @@ class LayoutFactory(object):
 
         if self.force:
             remove = self.operations_factory.create_remover(
-                self.file_helper.exists, self.dir_helper.rmtree)
-            renamer = self.operations_factory.create_force_rename(
-                renamer, remove)
+                self.file_helper.exists, self.dir_helper.rmtree
+            )
+            renamer = self.operations_factory.create_force_rename(renamer, remove)
 
         if self.verbose:
             renamer = self.operations_factory.create_verbose_rename(
-                renamer, self.output_stream)
+                renamer, self.output_stream
+            )
 
         # Build list of directories to process
         directories = [d for d in contents if self.is_underscore_dir(path, d)]
         underscore_directories = [
             self.handler_factory.create_dir_handler(d, path, renamer)
             for d in directories
-            ]
+        ]
 
         if not underscore_directories:
             if self.verbose:
                 self.output_stream.write(
                     "No top level directories starting with an underscore "
                     "were found in '%s'\n" % path
-                    )
+                )
             return NullLayout()
 
         # Build list of files that are in those directories
@@ -252,9 +255,9 @@ class LayoutFactory(object):
                     replacers.append(
                         self.operations_factory.create_replacer(
                             handler.relative_path(directory, f),
-                            handler.new_relative_path(directory, f)
-                            )
+                            handler.new_relative_path(directory, f),
                         )
+                    )
 
         # Build list of handlers to process all files
         filelist = []
@@ -265,25 +268,29 @@ class LayoutFactory(object):
                         self.handler_factory.create_file_handler(
                             self.file_helper.path_join(root, f),
                             replacers,
-                            self.file_helper.open_)
+                            self.file_helper.open_,
                         )
+                    )
                 if f.endswith(".js"):
                     filelist.append(
                         self.handler_factory.create_file_handler(
                             self.file_helper.path_join(root, f),
-                            [self.operations_factory
-                             .create_replacer("'_sources/'", "'sources/'")],
-                            self.file_helper.open_
-                            )
+                            [
+                                self.operations_factory.create_replacer(
+                                    "'_sources/'", "'sources/'"
+                                )
+                            ],
+                            self.file_helper.open_,
                         )
+                    )
 
         return Layout(underscore_directories, filelist)
 
     def is_underscore_dir(self, path, directory):
 
-        return (
-            self.dir_helper.is_dir(self.file_helper.path_join(path, directory))
-            and directory.startswith("_"))
+        return self.dir_helper.is_dir(
+            self.file_helper.path_join(path, directory)
+        ) and directory.startswith("_")
 
 
 def sphinx_extension(app, exception):
@@ -299,25 +306,18 @@ def sphinx_extension(app, exception):
 
     if exception:
         if app.config.sphinx_to_github_verbose:
-            msg = ("Sphinx-to-github: "
-                   "Exception raised in main build, doing nothing.")
+            msg = "Sphinx-to-github: " "Exception raised in main build, doing nothing."
             stdout(msg)
         return
 
-    dir_helper = DirHelper(
-        os.path.isdir,
-        os.listdir,
-        os.walk,
-        shutil.rmtree
-        )
+    dir_helper = DirHelper(os.path.isdir, os.listdir, os.walk, shutil.rmtree)
 
     file_helper = FileSystemHelper(
-        lambda f, mode:
-        codecs.open(f, mode, app.config.sphinx_to_github_encoding),
+        lambda f, mode: codecs.open(f, mode, app.config.sphinx_to_github_encoding),
         os.path.join,
         shutil.move,
-        os.path.exists
-        )
+        os.path.exists,
+    )
 
     operations_factory = OperationsFactory()
     handler_factory = HandlerFactory()
@@ -329,8 +329,8 @@ def sphinx_extension(app, exception):
         dir_helper,
         app.config.sphinx_to_github_verbose,
         sys.stdout,
-        force=True
-        )
+        force=True,
+    )
 
     layout = layout_factory.create_layout(app.outdir)
     layout.process()
@@ -351,36 +351,39 @@ def main(args):
     usage = "usage: %prog [options] <html directory>"
     parser = OptionParser(usage=usage)
     parser.add_option(
-        "-v", "--verbose", action="store_true",
-        dest="verbose", default=False, help="Provides verbose output")
+        "-v",
+        "--verbose",
+        action="store_true",
+        dest="verbose",
+        default=False,
+        help="Provides verbose output",
+    )
     parser.add_option(
-        "-e", "--encoding", action="store",
-        dest="encoding", default="utf-8",
-        help="Encoding for reading and writing files")
+        "-e",
+        "--encoding",
+        action="store",
+        dest="encoding",
+        default="utf-8",
+        help="Encoding for reading and writing files",
+    )
     opts, args = parser.parse_args(args)
 
     try:
         path = args[0]
     except IndexError:
         sys.stderr.write(
-            "Error - Expecting path to html directory:"
-            "sphinx-to-github <path>\n"
-            )
+            "Error - Expecting path to html directory:" "sphinx-to-github <path>\n"
+        )
         return
 
-    dir_helper = DirHelper(
-        os.path.isdir,
-        os.listdir,
-        os.walk,
-        shutil.rmtree
-        )
+    dir_helper = DirHelper(os.path.isdir, os.listdir, os.walk, shutil.rmtree)
 
     file_helper = FileSystemHelper(
         lambda f, mode: codecs.open(f, mode, opts.encoding),
         os.path.join,
         shutil.move,
-        os.path.exists
-        )
+        os.path.exists,
+    )
 
     operations_factory = OperationsFactory()
     handler_factory = HandlerFactory()
@@ -392,8 +395,8 @@ def main(args):
         dir_helper,
         opts.verbose,
         sys.stdout,
-        force=False
-        )
+        force=False,
+    )
 
     layout = layout_factory.create_layout(path)
     layout.process()
