@@ -8,7 +8,7 @@
 
 """
 **QtPy** is a shim over the various Python Qt bindings. It is used to write
-Qt binding indenpendent libraries or applications.
+Qt binding independent libraries or applications.
 
 If one of the APIs has already been imported, then it will be used.
 
@@ -62,12 +62,15 @@ packages::
 
 """
 
+from distutils.version import LooseVersion
 import os
 import platform
 import sys
+import warnings
 
 # Version of QtPy
 from ._version import __version__
+from .py3compat import PY2
 
 
 class PythonQtError(RuntimeError):
@@ -112,15 +115,17 @@ is_old_pyqt = is_pyqt46 = False
 PYQT5 = True
 PYQT4 = PYSIDE = PYSIDE2 = False
 
-
-if 'PyQt5' in sys.modules:
-    API = initial_api if initial_api in PYQT5_API else 'pyqt5'
-elif 'PySide2' in sys.modules:
-    API = initial_api if initial_api in PYSIDE2_API else 'pyside2'
-elif 'PyQt4' in sys.modules:
-    API = initial_api if initial_api in PYQT4_API else 'pyqt4'
-elif 'PySide' in sys.modules:
-    API = initial_api if initial_api in PYSIDE_API else 'pyside'
+# When `FORCE_QT_API` is set, we disregard
+# any previously imported python bindings.
+if not os.environ.get('FORCE_QT_API'):
+    if 'PyQt5' in sys.modules:
+        API = initial_api if initial_api in PYQT5_API else 'pyqt5'
+    elif 'PySide2' in sys.modules:
+        API = initial_api if initial_api in PYSIDE2_API else 'pyside2'
+    elif 'PyQt4' in sys.modules:
+        API = initial_api if initial_api in PYQT4_API else 'pyqt4'
+    elif 'PySide' in sys.modules:
+        API = initial_api if initial_api in PYSIDE_API else 'pyside'
 
 
 if API in PYQT5_API:
@@ -128,6 +133,23 @@ if API in PYQT5_API:
         from PyQt5.QtCore import PYQT_VERSION_STR as PYQT_VERSION  # analysis:ignore
         from PyQt5.QtCore import QT_VERSION_STR as QT_VERSION  # analysis:ignore
         PYSIDE_VERSION = None
+
+        if sys.platform == 'darwin':
+            macos_version = LooseVersion(platform.mac_ver()[0])
+            if macos_version < LooseVersion('10.10'):
+                if LooseVersion(QT_VERSION) >= LooseVersion('5.9'):
+                    raise PythonQtError("Qt 5.9 or higher only works in "
+                                        "macOS 10.10 or higher. Your "
+                                        "program will fail in this "
+                                        "system.")
+            elif macos_version < LooseVersion('10.11'):
+                if LooseVersion(QT_VERSION) >= LooseVersion('5.11'):
+                    raise PythonQtError("Qt 5.11 or higher only works in "
+                                        "macOS 10.11 or higher. Your "
+                                        "program will fail in this "
+                                        "system.")
+
+            del macos_version
     except ImportError:
         API = os.environ['QT_API'] = 'pyside2'
 
@@ -139,6 +161,17 @@ if API in PYSIDE2_API:
         PYQT_VERSION = None
         PYQT5 = False
         PYSIDE2 = True
+
+        if sys.platform == 'darwin':
+            macos_version = LooseVersion(platform.mac_ver()[0])
+            if macos_version < LooseVersion('10.11'):
+                if LooseVersion(QT_VERSION) >= LooseVersion('5.11'):
+                    raise PythonQtError("Qt 5.11 or higher only works in "
+                                        "macOS 10.11 or higher. Your "
+                                        "program will fail in this "
+                                        "system.")
+
+            del macos_version
     except ImportError:
         API = os.environ['QT_API'] = 'pyqt'
 
@@ -156,8 +189,13 @@ if API in PYQT4_API:
         except (AttributeError, ValueError):
             # PyQt < v4.6
             pass
-        from PyQt4.Qt import PYQT_VERSION_STR as PYQT_VERSION  # analysis:ignore
-        from PyQt4.Qt import QT_VERSION_STR as QT_VERSION  # analysis:ignore
+        try:
+            from PyQt4.Qt import PYQT_VERSION_STR as PYQT_VERSION  # analysis:ignore
+            from PyQt4.Qt import QT_VERSION_STR as QT_VERSION  # analysis:ignore
+        except ImportError:
+            # In PyQt4-sip 4.19.13 PYQT_VERSION_STR and QT_VERSION_STR are in PyQt4.QtCore
+            from PyQt4.QtCore import PYQT_VERSION_STR as PYQT_VERSION  # analysis:ignore
+            from PyQt4.QtCore import QT_VERSION_STR as QT_VERSION  # analysis:ignore
         PYSIDE_VERSION = None
         PYQT5 = False
         PYQT4 = True
@@ -177,6 +215,11 @@ if API in PYSIDE_API:
     except ImportError:
         raise PythonQtError('No Qt bindings could be found')
 
+# If a correct API name is passed to QT_API and it could not be found,
+# switches to another and informs through the warning
+if API != initial_api and binding_specified:
+    warnings.warn('Selected binding "{}" could not be found, '
+                  'using "{}"'.format(initial_api, API), RuntimeWarning)
 
 API_NAME = {'pyqt5': 'PyQt5', 'pyqt': 'PyQt4', 'pyqt4': 'PyQt4',
             'pyside': 'PySide', 'pyside2':'PySide2'}[API]
@@ -187,3 +230,10 @@ if PYQT4:
         API_NAME += (" (API v{0})".format(sip.getapi('QString')))
     except AttributeError:
         pass
+
+try:
+    # QtDataVisualization backward compatibility (QtDataVisualization vs. QtDatavisualization)
+    # Only available for Qt5 bindings > 5.9 on Windows
+    from . import QtDataVisualization as QtDatavisualization
+except ImportError:
+    pass
\ No newline at end of file
