@@ -1,6 +1,6 @@
 import os
 
-from . import PYSIDE, PYQT4, PYQT5
+from . import PYSIDE, PYSIDE2, PYQT4, PYQT5
 from .QtWidgets import QComboBox
 
 
@@ -12,9 +12,9 @@ elif PYQT4:
 
     from PyQt4.uic import *
 
-elif PYSIDE:
+else:
 
-    __all__ = ['loadUi']
+    __all__ = ['loadUi', 'loadUiType']
 
     # In PySide, loadUi does not exist, so we define it using QUiLoader, and
     # then make sure we expose that function. This is adapted from qt-helpers
@@ -78,8 +78,20 @@ elif PYSIDE:
     # FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
     # DEALINGS IN THE SOFTWARE.
 
-    from PySide.QtCore import QMetaObject
-    from PySide.QtUiTools import QUiLoader
+    if PYSIDE:
+        from PySide.QtCore import QMetaObject
+        from PySide.QtUiTools import QUiLoader
+        try:
+            from pysideuic import compileUi
+        except ImportError:
+            pass
+    elif PYSIDE2:
+        from PySide2.QtCore import QMetaObject
+        from PySide2.QtUiTools import QUiLoader
+        try:
+            from pyside2uic import compileUi
+        except ImportError:
+            pass
 
     class UiLoader(QUiLoader):
         """
@@ -177,7 +189,7 @@ elif PYSIDE:
 
         custom_widget_classes = {}
 
-        for custom_widget in custom_widgets.getchildren():
+        for custom_widget in list(custom_widgets):
 
             cw_class = custom_widget.find('class').text
             cw_header = custom_widget.find('header').text
@@ -222,3 +234,44 @@ elif PYSIDE:
         widget = loader.load(uifile)
         QMetaObject.connectSlotsByName(widget)
         return widget
+
+    def loadUiType(uifile, from_imports=False):
+        """Load a .ui file and return the generated form class and
+        the Qt base class.
+
+        The "loadUiType" command convert the ui file to py code
+        in-memory first and then execute it in a special frame to
+        retrieve the form_class.
+
+        Credit: https://stackoverflow.com/a/14195313/15954282
+        """
+
+        import sys
+        if sys.version_info >= (3, 0):
+            from io import StringIO
+        else:
+            from io import BytesIO as StringIO
+        from xml.etree.ElementTree import ElementTree
+        from . import QtWidgets
+
+        # Parse the UI file
+        etree = ElementTree()
+        ui = etree.parse(uifile)
+
+        widget_class = ui.find('widget').get('class')
+        form_class = ui.find('class').text
+
+        with open(uifile, 'r') as fd:
+            code_stream = StringIO()
+            frame = {}
+
+            compileUi(fd, code_stream, indent=0, from_imports=from_imports)
+            pyc = compile(code_stream.getvalue(), '<string>', 'exec')
+            exec(pyc, frame)
+
+            # Fetch the base_class and form class based on their type in the
+            # xml from designer
+            form_class = frame['Ui_%s' % form_class]
+            base_class = getattr(QtWidgets, widget_class)
+
+        return form_class, base_class
