@@ -1,21 +1,14 @@
-#!/usr/bin/env python
 """Test the cmds module"""
-from __future__ import absolute_import, division, unicode_literals
-
-try:
-    from unittest.mock import Mock, patch
-except ImportError:
-    from mock import Mock, patch
-
-import pytest
+from __future__ import absolute_import, division, print_function, unicode_literals
 
 from cola import cmds
 from cola.compat import uchr
 
+from .helper import Mock, patch
+
 
 def test_Commit_strip_comments():
     """Ensure that commit messages are stripped of comments"""
-
     msg = 'subject\n\n#comment\nbody'
     expect = 'subject\n\nbody\n'
     actual = cmds.Commit.strip_comments(msg)
@@ -24,7 +17,6 @@ def test_Commit_strip_comments():
 
 def test_commit_strip_comments_unicode():
     """Ensure that unicode is preserved in stripped commit messages"""
-
     msg = uchr(0x1234) + '\n\n#comment\nbody'
     expect = uchr(0x1234) + '\n\nbody\n'
     actual = cmds.Commit.strip_comments(msg)
@@ -227,7 +219,3 @@ def test_undo_last_commit_confirms_action(prefs, interaction):
     assert cmd.confirm()
     context.model.is_commit_published.assert_called_once()
     interaction.confirm.assert_called_once()
-
-
-if __name__ == '__main__':
-    pytest.main([__file__])
